import { authorize, requestWithDefaults } from "./util";

export type HypixelResponse<T> = Promise<
	{
		_response: Response;
		success: boolean;
	} & T
>;

export const ENDPOINT = "https://api.hypixel.net/";
const request = requestWithDefaults(ENDPOINT);

/**
 * Get Hypixel API key information
 * @param key API key
 * @returns A response with the API key information
 */
export async function getAPIKeyInformation(key: string): HypixelResponse<{
	record?: {
		key: string;
		owner: string;
		limit: number;
		queriesInPastMin: number;
		totalQueries: number;
	};
}> {
	let response = await request("/key", authorize(key));
	return {
		...(await response.json()),
		_response: response
	};
}
